@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from tests import apply_kwargs
+
 
 def a_response_data(**overrides):
     return apply_kwargs(overrides, {
@@ -20,3 +20,12 @@ def a_response_data(**overrides):
         "error_message": "",
         "data": {},
     })
+
+
+def apply_kwargs(kwargs, default_kwargs):
+    for k, v in kwargs.items():
+        if isinstance(v, dict):
+            default_kwargs[k] = apply_kwargs(v, default_kwargs[k])
+        else:
+            default_kwargs[k] = v
+    return default_kwargs
