@@ -11,11 +11,13 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 import unittest
 
 from hamcrest import assert_that, equal_to
 from mock import patch, MagicMock
 import ubersmith_client
+
 from tests.ubersmith_json.response_data_structure import a_response_data
 
 
@@ -70,7 +72,8 @@ class UbersmithRequestGetTest(unittest.TestCase):
         response.json = MagicMock(return_value=returning)
 
         def assert_called_with():
-            requests_mock.get.assert_called_with(auth=self.auth, params=kwargs, timeout=self.timeout, url=self.url)
+            requests_mock.get.assert_called_with(auth=self.auth, params=kwargs, timeout=self.timeout, url=self.url,
+                                                 headers={'user-agent': 'python-ubersmithclient'})
             response.json.assert_called_with()
 
         return assert_called_with
