@@ -11,11 +11,13 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 import unittest
 
 from hamcrest import assert_that, equal_to, calling, raises
 from mock import patch, MagicMock
 import ubersmith_client
+
 from tests.ubersmith_json.response_data_structure import a_response_data
 
 
@@ -81,7 +83,8 @@ class UbersmithRequestPostTest(unittest.TestCase):
         response.json = MagicMock(return_value=returning)
 
         def assert_called_with():
-            requests_mock.post.assert_called_with(auth=self.auth, timeout=self.timeout, url=self.url, data=kwargs)
+            requests_mock.post.assert_called_with(auth=self.auth, timeout=self.timeout, url=self.url, data=kwargs,
+                                                  headers={'user-agent': 'python-ubersmithclient'})
             response.json.assert_called_with()
 
         return assert_called_with
